@@ -531,8 +531,7 @@ sub completions_treeselection_changed_cb($$)
     {
 
         my ($iter,
-            $model,
-            $timeout_source_id);
+            $model);
         my $change_state = $completions->{details}->{change_state};
         my $combo_details = $completions->{details}->{combo_details};
         my $entry = $completions->{details}->{entry};
@@ -569,12 +568,15 @@ sub completions_treeselection_changed_cb($$)
 
         # Dismiss the completions list window in half a second or so.
 
-        $timeout_source_id =
+        $completions->{timeout_source_id} =
             Glib::Timeout->add(500,
                                sub {
+                                   my $completions = $_[0];
+                                   $completions->{timeout_source_id} = undef;
                                    hide_completions_window();
                                    return FALSE;
-                               });
+                               },
+                               $completions);
 
         # Update the parent window if necessary.
 
@@ -583,7 +585,6 @@ sub completions_treeselection_changed_cb($$)
 
         # We are done so make sure that the completions list window is hidden.
 
-        Glib::Source->remove($timeout_source_id);
         hide_completions_window();
 
     }
@@ -913,6 +914,8 @@ sub get_completions_window($$$$$)
                            $instance);
 
         $instance->{context_id} = undef;
+        $instance->{details} = undef;
+        $instance->{timeout_source_id} = undef;
 
     }
     else
@@ -1044,10 +1047,7 @@ sub get_tooltip_window($$$$)
     }
     else
     {
-        $instance->{in_cb} = 0;
-        local $instance->{in_cb} = 1;
-        $instance->{window}->hide();
-        Glib::Source->remove($instance->{timeout_source_id});
+        hide_tooltip_window();
     }
 
     local $instance->{in_cb} = 1;
@@ -1060,7 +1060,8 @@ sub get_tooltip_window($$$$)
         Glib::Timeout->add(3000,
                            sub {
                                my $instance = $_[0];
-                               $instance->{window}->hide();
+                               $instance->{timeout_source_id} = undef;
+                               hide_tooltip_window();
                                return FALSE;
                            },
                            $instance);
@@ -1157,6 +1158,11 @@ sub hide_completions_window()
             $instance->{togglebutton}->set_active(FALSE);
             $instance->{togglebutton} = undef;
         }
+        if (defined($instance->{timeout_source_id}))
+        {
+            Glib::Source->remove($instance->{timeout_source_id});
+            $instance->{timeout_source_id} = undef;
+        }
     }
 
 }
@@ -1191,7 +1197,11 @@ sub hide_tooltip_window()
         $instance->{in_cb} = 0;
         local $instance->{in_cb} = 1;
         $instance->{window}->hide();
-        Glib::Source->remove($instance->{timeout_source_id});
+        if (defined($instance->{timeout_source_id}))
+        {
+            Glib::Source->remove($instance->{timeout_source_id});
+            $instance->{timeout_source_id} = undef;
+        }
     }
 
 }
