@@ -118,6 +118,7 @@ sub run_command($$$$$$@);
 sub save_as_file($$$);
 sub set_label_value($$);
 sub set_window_size($$);
+sub shell_command(@);
 sub treeview_column_searcher($$$$);
 sub treeview_setup_search_column_selection($@);
 
@@ -260,13 +261,13 @@ sub run_command($$$$$$@)
 
             # In the parent process so deal with the error in the usual way.
 
-            my $dialog = Gtk2::MessageDialog->new
+            my $dialog = Gtk2::MessageDialog->new_with_markup
                 (undef,
                  ["modal"],
                  "warning",
                  "close",
                  __x("The {name} subprocess could not start,\n"
-                         . "the system gave:\n<b><i>{error_message}</b></i>",
+                         . "the system gave:\n<b><i>{error_message}</i></b>",
                      name => Glib::Markup::escape_text($args[0]),
                      error_message => Glib::Markup::escape_text($@)));
             busy_dialog_run($dialog);
@@ -468,6 +469,73 @@ sub run_command($$$$$$@)
 
     return 1;
 
+}
+#
+##############################################################################
+#
+#   Routine      - shell_command
+#
+#   Description  - Run the specified command in a shell. A simple replacement
+#                  for system(), which interferes with signal handling on some
+#                  systems.
+#
+#   Data         - @cmd : The command that is to be run. This can be in the
+#                         form of either a single string containing the
+#                         command with space separated arguments (optionally
+#                         using special shell characters if so desired) or
+#                         each work separated out into a list of separate
+#                         strings.
+#
+##############################################################################
+
+
+
+sub shell_command(@)
+{
+
+    my @cmd = @_;
+
+    my ($child,
+        $exit_status);
+
+    if (($child = fork()) == 0)
+    {
+
+        # In Perl all file handles have FD_CLOEXEC set by default and so we
+        # only need to worry about resetting signal handlers to their default
+        # disposition before making the exec call.
+
+        foreach my $sig (keys(%SIG))
+        {
+            $SIG{$sig} = "DEFAULT";
+        }
+        exec(@cmd) or _exit($!);
+
+    }
+
+    # Wait a bit and them make sure that things have worked ok.
+
+    sleep(1);
+    if (! defined($child)
+        || (cached_waitpid($child, WNOHANG, \$exit_status) == $child
+            && ! (WIFEXITED($exit_status) && WEXITSTATUS($exit_status) == 0)))
+    {
+        $! = WEXITSTATUS($exit_status)
+            if (defined($exit_status) && WIFEXITED($exit_status));
+        my $prog = (split(/ /, $cmd[0]))[0];
+        my $dialog = Gtk2::MessageDialog->new_with_markup
+            (undef,
+             ["modal"],
+             "warning",
+             "close",
+             __x("The {name} subprocess could not start,\n"
+                     . "the system gave:\n<b><i>{error_message}</i></b>",
+                 name => Glib::Markup::escape_text($prog),
+                 error_message => Glib::Markup::escape_text($!)));
+        busy_dialog_run($dialog);
+        $dialog->destroy();
+    }
+
 }
 #
 ##############################################################################
@@ -619,7 +687,8 @@ sub open_database($$$)
     while (! $done);
 
     $file_chooser_dir_locations{open_db_dir} =
-        $chooser_dialog->get_current_folder();
+        $chooser_dialog->get_current_folder()
+        if (defined($chooser_dialog->get_current_folder()));
     $chooser_dialog->destroy();
 
     return $ret_val;
@@ -868,7 +937,8 @@ sub save_as_file($$$)
     while (! $done);
 
     $file_chooser_dir_locations{save_as_dir} =
-        $chooser_dialog->get_current_folder();
+        $chooser_dialog->get_current_folder()
+        if (defined($chooser_dialog->get_current_folder()));
     $chooser_dialog->destroy();
 
 }
@@ -1793,7 +1863,7 @@ sub display_html($)
 
         # Launch it.
 
-        system($cmd . " &");
+        shell_command($cmd);
 
     }
 
